@@ -1,10 +1,6 @@
-
 package MouseX::Getopt::Meta::Attribute::NoGetopt;
 use Mouse;
 
-our $VERSION   = '0.2600';
-our $AUTHORITY = 'cpan:STEVAN';
-
 extends 'Mouse::Meta::Attribute'; # << Mouse extending Mouse :)
    with 'MouseX::Getopt::Meta::Attribute::Trait::NoGetopt';
 
@@ -56,25 +52,8 @@ metaclass.
 
 =back
 
-=head1 BUGS
+=head1 SEE ALSO
 
-All complex software has bugs lurking in it, and this module is no 
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT.
-
-=head1 AUTHOR
-
-Stevan Little E<lt>stevan@iinteractive.comE<gt>
-
-Chris Prather  C<< <perigrin@cpan.org> >>
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright 2007-2008 by Infinity Interactive, Inc.
-
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+L<MouseX::Getopt>
 
 =cut
