@@ -1,9 +1,9 @@
+
 package MouseX::Getopt::OptionTypeMap;
 
 use Mouse 'confess', 'blessed';
 use Mouse::Util::TypeConstraints 'find_type_constraint';
 
-
 my %option_type_map = (
     'Bool'     => '!',
     'Str'      => '=s',
@@ -66,9 +66,8 @@ sub add_option_type_to_map {
     $option_type_map{$type_name} = $option_string;
 }
 
-no Mouse;
-no Mouse::Util::TypeConstraints;
-1;
+no Mouse; no Mouse::Util::TypeConstraints; 1;
+
 __END__
 
 
@@ -99,25 +98,8 @@ These are all class methods and should be called as such.
 
 =back
 
-=head1 BUGS
+=head1 SEE ALSO
 
-All complex software has bugs lurking in it, and this module is no 
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT.
-
-=head1 AUTHOR
-
-NAKAGAWA Masaki E<lt>masaki@cpan.orgE<gt>
-
-FUJI Goro E<lt>gfuji@cpan.orgE<gt> from 0.22
-
-=head1 OROGINAL AUTHOR
-
-See L<MooseX::Getopt/AUTHOR> and L<MooseX::Getopt/CONTRIBUTORS>.
-
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+L<MouseX::Getopt>
 
 =cut
